@@ -1,6 +1,8 @@
 # PYTHON_ARGCOMPLETE_OK
 # -*- coding: UTF-8 -*-
 
+import site
+
 from arghandler import subcmd, ArgumentHandler
 
 from kntgen import __version__
@@ -12,8 +14,6 @@ from kntgen.parser_helpers import *
 from kntgen.printer import *
 from kntgen.ui.figma_ui_generator import FigmaUIGenerator
 
-import site
-
 
 @subcmd('sample', help=DefinedCmd.HELP_CMD_SAMPLE)
 def cmd_sample(parser, _, args):
@@ -44,16 +44,16 @@ def cmd_sample(parser, _, args):
         parser.error(DefinedErrorMessage.ERROR_SUPPORT_FORMAT)
 
     # Print the sample
-    root = f'{site.getsitepackages()[0]}/kntgen_templates'
+    root = f'kntgen.kntgen_templates'
     file_path = ''
     if template == SUPPORTED_TEMPLATES[0]:
-        file_path = '/bloc/sample_input/sample_bloc'
+        file_path = '.bloc.sample_input.sample_bloc'
     elif template == SUPPORTED_TEMPLATES[1]:
-        file_path = '/json_to_dart/sample_input/sample'
+        file_path = '.json_to_dart.sample_input.sample'
     elif template == SUPPORTED_TEMPLATES[2]:
-        file_path = '/network/sample_input/sample_network'
+        file_path = '.network.sample_input.sample_network'
     elif template == SUPPORTED_TEMPLATES[3]:
-        file_path = '/ui/sample_input/kntgen_config'
+        file_path = '.ui.sample_input.kntgen_config'
         # UI config only accept .yaml
         extension = SUPPORTED_SOURCE_FORMAT[1]
     file_path = root + file_path + '.' + extension
